@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod
 version: 1.4.2.1
-id: yesod-1.4.2.1-45946f0420543e26c8db49723cd72dc7
-key: yesod_FEz5b6L6wgCAdWS0S8WgKm
+id: yesod-1.4.2.1-9acb9e7a6ee115120170493743d7f9b0
+key: yesod_Evp98OKFqZ83RLCG5CnVTt
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -21,19 +21,19 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-1.4.2.1
-hs-libraries: HSyesod-1.4.2.1-FEz5b6L6wgCAdWS0S8WgKm
+hs-libraries: HSyesod-1.4.2.1-Evp98OKFqZ83RLCG5CnVTt
 depends:
     aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     blaze-html-0.8.1.1-1d54daeba5477a1aa0462b832a558865
     blaze-markup-0.7.0.3-fed4a147945def017f9ea9594b30666a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-extra-1.1.11-ff8bfc3f034dbe9a6e5b1cd3f1929886
+    conduit-extra-1.1.12-6ce48f5ff8e654a7180ec1d44ce2af13
     data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     fast-logger-2.4.1-5b4c33804a079c795a3744fd9f8cdcd3
     monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
-    monad-logger-0.3.18-0974645d267a817a7b3484945a31ce66
+    monad-logger-0.3.18-4dbf6be6e769b875a57cb442a747af6f
     safe-0.3.9-b613242f536083d5bb04920ede356aea
     semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
     shakespeare-2.0.8-88acbcac23cb55d5f3c82ebba9b11159
@@ -43,15 +43,15 @@ depends:
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
     unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
-    wai-3.2.0-7ea0a12f4ecd69f2ebdeef193a494430
-    wai-extra-3.0.15-954ac840c460f6e3c2fb191ca01c5fce
-    wai-logger-2.2.4.1-9478a6051df96b8d5b3214f7fcca2185
-    warp-3.2.3-6de819de378ae4c57281b63b66004254
+    wai-3.2.0.1-d9757c75f497737a542bd24e4c437c56
+    wai-extra-3.0.15-2f88b45989ced36024c3ff3943866d23
+    wai-logger-2.2.4.1-fb66803d5627851b4e6cf4f9505489de
+    warp-3.2.4-afffa286f2a73716d3c875d3f70e8c61
     yaml-0.8.16-50dd72d7df25e45cd672d7359cb18648
-    yesod-auth-1.4.12-4d106a89bc5f54fb1850e8a22c0b22dc
-    yesod-core-1.4.19-b6ec8d224ea1c49c36126eee73b10ab6
-    yesod-form-1.4.6-6e5c019f77bbb31f3f8cbc24ba3a758a
-    yesod-persistent-1.4.0.3-c6542cb45d0d37a797eae519cf194b16
+    yesod-auth-1.4.13-13eb60b8c85ce30ea4df6345e87fa407
+    yesod-core-1.4.20-239146128fca65f6c1bc44de3eec675c
+    yesod-form-1.4.7-f87c54f7a3a15348d1b5848f4d13423d
+    yesod-persistent-1.4.0.4-0995ca503f60c66644376333828a57d7
 haddock-interfaces: /usr/share/doc/haskell-yesod/html/yesod.haddock
 haddock-html: /usr/share/doc/haskell-yesod/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
